import SwiftUI

struct SingleKeyView: View {

    @State
    private var needRefresh = false

    @Binding
    var keyManager: KeyManagement

    let type: KeyManagement.KeyType

    private var generateText: String {
        hasKey ? "Generate" : "Regenerate"
    }

    var hasKey: Bool {
        keyManager.has(type)
    }

    var content: String {
        keyManager.get(type)?.displayString ?? "-"
    }

    var body: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text(type.displayName)
                .bold()
            Text(needRefresh ? content : content)
                .font(.system(.body, design: .monospaced))
            HStack() {
                Button(generateText) {
                    keyManager.generate(type)
                    needRefresh.toggle()
                }
                .padding()
                Button("Copy") {
                    UIPasteboard.general.string = content
                }
                .disabled(!hasKey)
                .padding()
                Spacer()
            }
        }
    }
}

struct SingleKeyView_Previews: PreviewProvider {
    static var previews: some View {
        SingleKeyView(
            keyManager: .constant(KeyManagement()),
            type: .deviceKey)
    }
}
